@@ -54,6 +54,34 @@ class DcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ApplyInternetAddress(self, request):
+        """This API is used to apply for an internet tunnel’s CIDR block.
+
+        :param request: Request instance for ApplyInternetAddress.
+        :type request: :class:`tencentcloud.dc.v20180410.models.ApplyInternetAddressRequest`
+        :rtype: :class:`tencentcloud.dc.v20180410.models.ApplyInternetAddressResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ApplyInternetAddress", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ApplyInternetAddressResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateDirectConnect(self, request):
         """This API is used to apply for a connection.
         When calling this API, please note that:
@@ -254,6 +282,146 @@ class DcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeInternetAddress(self, request):
+        """This API is used to obtain the public IP address of an internet tunnel.
+
+        :param request: Request instance for DescribeInternetAddress.
+        :type request: :class:`tencentcloud.dc.v20180410.models.DescribeInternetAddressRequest`
+        :rtype: :class:`tencentcloud.dc.v20180410.models.DescribeInternetAddressResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeInternetAddress", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeInternetAddressResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeInternetAddressQuota(self, request):
+        """This API is used to obtain the public IP quota of internet tunnels.
+
+        :param request: Request instance for DescribeInternetAddressQuota.
+        :type request: :class:`tencentcloud.dc.v20180410.models.DescribeInternetAddressQuotaRequest`
+        :rtype: :class:`tencentcloud.dc.v20180410.models.DescribeInternetAddressQuotaResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeInternetAddressQuota", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeInternetAddressQuotaResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeInternetAddressStatistics(self, request):
+        """This API is used to obtain the public IP address assignment statistics of internet tunnels.
+
+        :param request: Request instance for DescribeInternetAddressStatistics.
+        :type request: :class:`tencentcloud.dc.v20180410.models.DescribeInternetAddressStatisticsRequest`
+        :rtype: :class:`tencentcloud.dc.v20180410.models.DescribeInternetAddressStatisticsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeInternetAddressStatistics", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeInternetAddressStatisticsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DisableInternetAddress(self, request):
+        """This API is used to disable a public IP address of internet tunnels.
+
+        :param request: Request instance for DisableInternetAddress.
+        :type request: :class:`tencentcloud.dc.v20180410.models.DisableInternetAddressRequest`
+        :rtype: :class:`tencentcloud.dc.v20180410.models.DisableInternetAddressResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DisableInternetAddress", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DisableInternetAddressResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def EnableInternetAddress(self, request):
+        """This API is used to enable a public IP address for internet tunnels.
+
+        :param request: Request instance for EnableInternetAddress.
+        :type request: :class:`tencentcloud.dc.v20180410.models.EnableInternetAddressRequest`
+        :rtype: :class:`tencentcloud.dc.v20180410.models.EnableInternetAddressResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("EnableInternetAddress", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.EnableInternetAddressResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyDirectConnectAttribute(self, request):
         """This API is used to modify connection attributes.
 
@@ -331,6 +499,34 @@ class DcClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ReleaseInternetAddress(self, request):
+        """This API is used to release an IP address of internet tunnels.
+
+        :param request: Request instance for ReleaseInternetAddress.
+        :type request: :class:`tencentcloud.dc.v20180410.models.ReleaseInternetAddressRequest`
+        :rtype: :class:`tencentcloud.dc.v20180410.models.ReleaseInternetAddressResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ReleaseInternetAddress", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ReleaseInternetAddressResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
